.. Jigna documentation master file, created by
   sphinx-quickstart on Sun Feb  9 19:23:03 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the Jigna documentation!
===================================

Jigna allows you to create a HTML/CSS/Javascript based user interface for a
Python application. The UI can be viewed either in a Qt-based application or
entirely on a web-browser.


.. toctree::
   :maxdepth: 2

   intro




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
